@@ -18,17 +18,23 @@ class AbstractResource;
 class DISCOVERCOMMON_EXPORT TransactionListener : public QObject
 {
     Q_OBJECT
-    Q_PROPERTY(AbstractResource* resource READ resource WRITE setResource NOTIFY resourceChanged)
-    Q_PROPERTY(Transaction* transaction READ transaction WRITE setTransaction NOTIFY transactionChanged)
+    Q_PROPERTY(AbstractResource *resource READ resource WRITE setResource NOTIFY resourceChanged)
+    Q_PROPERTY(Transaction *transaction READ transaction WRITE setTransaction NOTIFY transactionChanged)
     Q_PROPERTY(bool isCancellable READ isCancellable NOTIFY cancellableChanged)
     Q_PROPERTY(bool isActive READ isActive NOTIFY isActiveChanged)
     Q_PROPERTY(QString statusText READ statusText NOTIFY statusTextChanged)
     Q_PROPERTY(int progress READ progress NOTIFY progressChanged)
 public:
     explicit TransactionListener(QObject *parent = nullptr);
-    
-    AbstractResource *resource() const { return m_resource; }
-    Transaction *transaction() const { return m_transaction; }
+
+    AbstractResource *resource() const
+    {
+        return m_resource;
+    }
+    Transaction *transaction() const
+    {
+        return m_transaction;
+    }
     bool isCancellable() const;
     bool isActive() const;
     QString statusText() const;
@@ -36,14 +42,14 @@ public:
 
     Q_SCRIPTABLE void cancel();
 
-    void setResource(AbstractResource* resource);
+    void setResource(AbstractResource *resource);
     void setTransaction(Transaction *trans);
 
 private:
-    void setResourceInternal(AbstractResource* resource);
+    void setResourceInternal(AbstractResource *resource);
 
     AbstractResource *m_resource;
-    Transaction* m_transaction;
+    Transaction *m_transaction;
 
 private Q_SLOTS:
     void transactionAdded(Transaction *trans);
@@ -56,7 +62,7 @@ Q_SIGNALS:
     void statusTextChanged();
     void cancelled();
     void progressChanged();
-    void transactionChanged(Transaction* transaction);
+    void transactionChanged(Transaction *transaction);
 };
 
 #endif // TRANSACTIONLISTENER_H
