@@ -1,33 +1,19 @@
-/***************************************************************************
- *   Copyright © 2012 Jonathan Thomas <echidnaman@kubuntu.org>             *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or         *
- *   modify it under the terms of the GNU General Public License as        *
- *   published by the Free Software Foundation; either version 2 of        *
- *   the License or (at your option) version 3 or any later version        *
- *   accepted by the membership of KDE e.V. (or its successor approved     *
- *   by the membership of KDE e.V.), which shall act as a proxy            *
- *   defined in Section 14 of version 3 of the license.                    *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
- ***************************************************************************/
+/*
+ *   SPDX-FileCopyrightText: 2012 Jonathan Thomas <echidnaman@kubuntu.org>
+ *
+ *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+ */
 
 #include "TransactionModel.h"
 
 // Qt includes
+#include <KLocalizedString>
 #include <QDebug>
 #include <QMetaProperty>
-#include <KLocalizedString>
 
 // Own includes
-#include "resources/AbstractResource.h"
 #include "libdiscover_debug.h"
+#include "resources/AbstractResource.h"
 
 Q_GLOBAL_STATIC(TransactionModel, globalTransactionModel)
 
@@ -44,7 +30,7 @@ TransactionModel::TransactionModel(QObject *parent)
     connect(this, &TransactionModel::countChanged, this, &TransactionModel::progressChanged);
 }
 
-QHash< int, QByteArray > TransactionModel::roleNames() const
+QHash<int, QByteArray> TransactionModel::roleNames() const
 {
     QHash<int, QByteArray> roles;
     roles[TransactionRoleRole] = "transactionRole";
@@ -109,9 +95,9 @@ QVariant TransactionModel::data(const QModelIndex &index, int role) const
         }
         break;
     case TransactionRole:
-        return QVariant::fromValue<QObject*>(trans);
+        return QVariant::fromValue<QObject *>(trans);
     case ResourceRole:
-        return QVariant::fromValue<QObject*>(trans->resource());
+        return QVariant::fromValue<QObject *>(trans->resource());
     }
 
     return QVariant();
@@ -148,25 +134,32 @@ QModelIndex TransactionModel::indexOf(AbstractResource *res) const
 
 void TransactionModel::addTransaction(Transaction *trans)
 {
-    if(!trans)
+    if (!trans)
         return;
 
     if (m_transactions.contains(trans))
         return;
 
     if (m_transactions.isEmpty())
-        emit startingFirstTransaction();
+        Q_EMIT startingFirstTransaction();
 
     int before = m_transactions.size();
     beginInsertRows(QModelIndex(), before, before + 1);
     m_transactions.append(trans);
     endInsertRows();
 
-    connect(trans, &Transaction::statusChanged, this, [this](){ transactionChanged(StatusTextRole); });
-    connect(trans, &Transaction::cancellableChanged, this, [this](){ transactionChanged(CancellableRole); });
-    connect(trans, &Transaction::progressChanged, this, [this](){ transactionChanged(ProgressRole); Q_EMIT progressChanged(); });
+    connect(trans, &Transaction::statusChanged, this, [this]() {
+        transactionChanged(StatusTextRole);
+    });
+    connect(trans, &Transaction::cancellableChanged, this, [this]() {
+        transactionChanged(CancellableRole);
+    });
+    connect(trans, &Transaction::progressChanged, this, [this]() {
+        transactionChanged(ProgressRole);
+        Q_EMIT progressChanged();
+    });
 
-    emit transactionAdded(trans);
+    Q_EMIT transactionAdded(trans);
 }
 
 void TransactionModel::removeTransaction(Transaction *trans)
@@ -174,7 +167,7 @@ void TransactionModel::removeTransaction(Transaction *trans)
     Q_ASSERT(trans);
     trans->deleteLater();
     int r = m_transactions.indexOf(trans);
-    if (r<0) {
+    if (r < 0) {
         qCWarning(LIBDISCOVER_LOG) << "transaction not part of the model" << trans;
         return;
     }
@@ -185,27 +178,27 @@ void TransactionModel::removeTransaction(Transaction *trans)
     m_transactions.removeAt(r);
     endRemoveRows();
 
-    emit transactionRemoved(trans);
+    Q_EMIT transactionRemoved(trans);
     if (m_transactions.isEmpty())
-        emit lastTransactionFinished();
+        Q_EMIT lastTransactionFinished();
 }
 
 void TransactionModel::transactionChanged(int role)
 {
     Transaction *trans = qobject_cast<Transaction *>(sender());
     QModelIndex transIdx = indexOf(trans);
-    emit dataChanged(transIdx, transIdx, {role});
+    Q_EMIT dataChanged(transIdx, transIdx, {role});
 }
 
 int TransactionModel::progress() const
 {
     int sum = 0;
     int count = 0;
-    foreach(Transaction* t, m_transactions) {
+    foreach (Transaction *t, m_transactions) {
         if (t->isActive() && t->isVisible()) {
             sum += t->progress();
             ++count;
         }
     }
-    return count==0 ? 0 : sum / count;
+    return count == 0 ? 0 : sum / count;
 }
